abacusai.code_bot — AbacusAI documentation

# abacusai.code_bot

## Classes

`CodeBot` | A bot option for CodeLLM

## Module Contents

class abacusai.code_bot.CodeBot(client, llmName=None, name=None, imageUploadSupported=None, codeAgentSupported=None, codeEditSupported=None, isPremium=None, llmBotIcon=None, provider=None, isUserApiKeyAllowed=None, isRateLimited=None, apiKeyUrl=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A bot option for CodeLLM

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - llmName (str) – The name of the LLM.

    - name (str) – The name of the bot.

    - imageUploadSupported (bool) – Whether the LLM supports image upload.

    - codeAgentSupported (bool) – Whether the LLM supports code agent.

    - codeEditSupported (bool) – Whether the LLM supports code edit.

    - isPremium (bool) – Whether the LLM is a premium LLM.

    - llmBotIcon (str) – The icon of the LLM bot.

    - provider (str) – The provider of the LLM.

    - isUserApiKeyAllowed (bool) – Whether the LLM supports user API key.

    - isRateLimited (bool) – Whether the LLM is rate limited.

    - apiKeyUrl (str) – The URL to get the API key.

  llm_name = None
  name = None
  image_upload_supported = None
  code_agent_supported = None
  code_edit_supported = None
  is_premium = None
  llm_bot_icon = None
  provider = None
  is_user_api_key_allowed = None
  is_rate_limited = None
  api_key_url = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict